km3pipe\.core\.Geometry
=======================

.. currentmodule:: km3pipe.core

.. autoclass:: Geometry

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Geometry.__init__
      ~Geometry.add
      ~Geometry.apply
      ~Geometry.configure
      ~Geometry.finish
      ~Geometry.get
      ~Geometry.get_detector
      ~Geometry.pre_finish
      ~Geometry.process
      ~Geometry.require
   
   

   
   
   